==> kubernetes-model-apiextensions-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrBoolFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrBoolFluent<A extends JSONSchemaPropsOrBoolFluent<A>> extends Fluent<A>{
  public Boolean getAllows();
  public A withAllows(Boolean allows);
  public Boolean hasAllows();
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getSchema();
  public JSONSchemaProps buildSchema();
  public A withSchema(JSONSchemaProps schema);
  public Boolean hasSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> withNewSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> withNewSchemaLike(JSONSchemaProps item);
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editOrNewSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editOrNewSchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withAllows();
  public interface SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<JSONSchemaPropsOrBoolFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrBoolFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface JSONSchemaPropsOrBoolFluent<A extends JSONSchemaPropsOrBoolFluent<A>> extends Fluent<A>{
  public Boolean getAllows();
  public A withAllows(Boolean allows);
  public Boolean hasAllows();
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @Deprecated
  public JSONSchemaProps getSchema();
  public JSONSchemaProps buildSchema();
  public A withSchema(JSONSchemaProps schema);
  public Boolean hasSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> withNewSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> withNewSchemaLike(JSONSchemaProps item);
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editOrNewSchema();
  public JSONSchemaPropsOrBoolFluent.SchemaNested<A> editOrNewSchemaLike(JSONSchemaProps item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withAllows();
  public interface SchemaNested<N> extends Nested<N>,JSONSchemaPropsFluent<JSONSchemaPropsOrBoolFluent.SchemaNested<N>>{
    public N and();
    public N endSchema();
    
  }
  
}
